@@ -1,9 +1,3 @@
 (function() {var implementors = {};
 implementors["run_script"] = [{"text":"impl <a class=\"trait\" href=\"https://doc.rust-lang.org/nightly/core/fmt/trait.Display.html\" title=\"trait core::fmt::Display\">Display</a> for <a class=\"struct\" href=\"run_script/types/struct.ScriptError.html\" title=\"struct run_script::types::ScriptError\">ScriptError</a>","synthetic":false,"types":["run_script::types::ScriptError"]}];
-
-            if (window.register_implementors) {
-                window.register_implementors(implementors);
-            } else {
-                window.pending_implementors = implementors;
-            }
-        })()
\ No newline at end of file
+if (window.register_implementors) {window.register_implementors(implementors);} else {window.pending_implementors = implementors;}})()
\ No newline at end of file
