@@ -1,9 +1,3 @@
 (function() {var implementors = {};
 implementors["run_script"] = [{"text":"impl Freeze for <a class=\"struct\" href=\"run_script/types/struct.ScriptError.html\" title=\"struct run_script::types::ScriptError\">ScriptError</a>","synthetic":true,"types":["run_script::types::ScriptError"]},{"text":"impl Freeze for <a class=\"struct\" href=\"run_script/types/struct.ScriptOptions.html\" title=\"struct run_script::types::ScriptOptions\">ScriptOptions</a>","synthetic":true,"types":["run_script::types::ScriptOptions"]},{"text":"impl Freeze for <a class=\"enum\" href=\"run_script/types/enum.ErrorInfo.html\" title=\"enum run_script::types::ErrorInfo\">ErrorInfo</a>","synthetic":true,"types":["run_script::types::ErrorInfo"]},{"text":"impl Freeze for <a class=\"enum\" href=\"run_script/types/enum.IoOptions.html\" title=\"enum run_script::types::IoOptions\">IoOptions</a>","synthetic":true,"types":["run_script::types::IoOptions"]}];
-
-            if (window.register_implementors) {
-                window.register_implementors(implementors);
-            } else {
-                window.pending_implementors = implementors;
-            }
-        })()
\ No newline at end of file
+if (window.register_implementors) {window.register_implementors(implementors);} else {window.pending_implementors = implementors;}})()
\ No newline at end of file
