@@ -2,14 +2,16 @@
     absolute_paths_not_starting_with_crate,
     ambiguous_associated_items,
     anonymous_parameters,
+    arithmetic_overflow,
     array_into_iter,
     bindings_with_variant_name,
+    coherence_leak_check,
+    conflicting_repr_hints,
     const_err,
     dead_code,
     deprecated,
     deprecated_in_future,
     ellipsis_inclusive_range_patterns,
-    exceeding_bitshifts,
     explicit_outlives_requirements,
     exported_private_dependencies,
     ill_formed_attribute_input,
@@ -17,6 +19,8 @@
     improper_ctypes,
     incomplete_features,
     indirect_structural_match,
+    inline_no_sanitize,
+    invalid_codeblock_attribute,
     invalid_type_param_default,
     invalid_value,
     irrefutable_let_patterns,
@@ -25,6 +29,7 @@
     macro_expanded_macro_exports_accessed_by_absolute_paths,
     meta_variable_misuse,
     missing_copy_implementations,
+    missing_crate_level_docs,
     missing_docs,
     missing_fragment_specifier,
     mutable_borrow_reservation_conflict,
@@ -45,7 +50,7 @@
     private_in_public,
     proc_macro_derive_resolution_fallback,
     pub_use_of_private_extern_crate,
-    redundant_semicolon,
+    redundant_semicolons,
     safe_packed_borrows,
     soft_unstable,
     stable_features,
@@ -55,6 +60,7 @@
     type_alias_bounds,
     tyvar_behind_raw_pointer,
     uncommon_codepoints,
+    unconditional_panic,
     unconditional_recursion,
     unknown_crate_types,
     unnameable_test_items,
@@ -67,6 +73,7 @@
     unused_allocation,
     unused_assignments,
     unused_attributes,
+    unused_braces,
     unused_comparisons,
     unused_doc_comments,
     unused_extern_crates,
@@ -113,9 +120,7 @@
 //!
 //! ## Basic Example
 //!
-//! ````
-//! extern crate run_script;
-//!
+//! ````use run_script;
 //! use run_script::ScriptOptions;
 //!
 //! fn main() {
@@ -126,12 +131,13 @@
 //!     // run the script and get the script execution output
 //!     let (code, output, error) = run_script::run(
 //!         r#"
-//!         echo "Directory Info:"
-//!         dir
-//!         "#,
+//!          echo "Directory Info:"
+//!          dir
+//!          "#,
 //!         &args,
-//!         &options
-//!     ).unwrap();
+//!         &options,
+//!     )
+//!     .unwrap();
 //!
 //!     println!("Exit Code: {}", code);
 //!     println!("Output: {}", output);
@@ -140,12 +146,13 @@
 //!     // run the script and get a handle to the running child process
 //!     let child = run_script::spawn(
 //!         r#"
-//!         echo "Directory Info:"
-//!         dir
-//!         "#,
+//!          echo "Directory Info:"
+//!          dir
+//!          "#,
 //!         &args,
-//!         &options
-//!     ).unwrap();
+//!         &options,
+//!     )
+//!     .unwrap();
 //!
 //!     let spawn_output = child.wait_with_output().unwrap();
 //!
@@ -156,19 +163,17 @@
 //! ## Macro Examples
 //!
 //! ```rust
-//! #[macro_use]
-//! extern crate run_script;
-//!
 //! use run_script::ScriptOptions;
 //!
 //! fn main() {
 //!     // simple call to run script with only the script text
-//!     let (code, output, error) = run_script!(
+//!     let (code, output, error) = run_script::run_script!(
 //!         r#"
-//!         echo "Test"
-//!         exit 0
-//!         "#
-//!     ).unwrap();
+//!          echo "Test"
+//!          exit 0
+//!          "#
+//!     )
+//!     .unwrap();
 //!
 //!     println!("Exit Code: {}", code);
 //!     println!("Output: {}", output);
@@ -176,13 +181,14 @@
 //!
 //!     // run script invoked with the script text and options
 //!     let options = ScriptOptions::new();
-//!     let (code, output, error) = run_script!(
+//!     let (code, output, error) = run_script::run_script!(
 //!         r#"
-//!         echo "Test"
-//!         exit 0
-//!         "#,
+//!          echo "Test"
+//!          exit 0
+//!          "#,
 //!         &options
-//!     ).unwrap();
+//!     )
+//!     .unwrap();
 //!
 //!     println!("Exit Code: {}", code);
 //!     println!("Output: {}", output);
@@ -190,22 +196,28 @@
 //!
 //!     // run script invoked with all arguments
 //!     let options = ScriptOptions::new();
-//!     let (code, output, error) = run_script!(
+//!     let (code, output, error) = run_script::run_script!(
 //!         r#"
-//!         echo "Test"
-//!         exit 0
-//!         "#,
+//!          echo "Test"
+//!          exit 0
+//!          "#,
 //!         &vec!["ARG1".to_string(), "ARG2".to_string()],
 //!         &options
-//!     ).unwrap();
+//!     )
+//!     .unwrap();
+//!
+//!     println!("Exit Code: {}", code);
+//!     println!("Output: {}", output);
+//!     println!("Error: {}", error);
 //!
 //!     // spawn_script! works the same as run_script! but returns the child process handle
-//!     let child = spawn_script!(
+//!     let child = run_script::spawn_script!(
 //!         r#"
-//!         echo "Test"
-//!         exit 0
-//!         "#
-//!     ).unwrap();
+//!          echo "Test"
+//!          exit 0
+//!          "#
+//!     )
+//!     .unwrap();
 //!
 //!     println!("PID: {}", child.id());
 //! }
@@ -231,6 +243,9 @@
 #[path = "./lib_test.rs"]
 mod lib_test;
 
+#[cfg(doctest)]
+doc_comment::doctest!("../README.md");
+
 #[macro_use]
 mod macros;
 mod runner;
@@ -258,8 +273,6 @@ pub type IoOptions = types::IoOptions;
 /// # Example
 ///
 /// ````
-/// extern crate run_script;
-///
 /// use run_script::ScriptOptions;
 ///
 /// fn main() {
@@ -300,8 +313,6 @@ pub fn run(
 /// # Example
 ///
 /// ````
-/// extern crate run_script;
-///
 /// use run_script::ScriptOptions;
 ///
 /// fn main() {
@@ -339,8 +350,6 @@ pub fn spawn(
 /// # Example
 ///
 /// ````
-/// extern crate run_script;
-///
 /// use run_script::ScriptOptions;
 ///
 /// fn main() {
