@@ -12,6 +12,7 @@ use std::error;
 use std::fmt;
 use std::fmt::Display;
 use std::io::Error;
+use std::path::PathBuf;
 
 #[derive(Debug)]
 /// Holds the error information
@@ -57,6 +58,8 @@ impl Display for ScriptError {
 pub struct ScriptOptions {
     /// Defines the requested runner (defaults to cmd in windows and sh for other platforms)
     pub runner: Option<String>,
+    /// The working directory of the invocation
+    pub working_directory: Option<PathBuf>,
     /// Default is IoOptions::Inherit
     pub input_redirection: IoOptions,
     /// Default is IoOptions::Pipe (only pipe enables to capture the output)
@@ -83,6 +86,7 @@ impl ScriptOptions {
     pub fn new() -> ScriptOptions {
         ScriptOptions {
             runner: None,
+            working_directory: None,
             input_redirection: IoOptions::Inherit,
             output_redirection: IoOptions::Pipe,
             exit_on_error: false,
